summaryrefslogtreecommitdiff
path: root/python/lowlevelil.py
diff options
context:
space:
mode:
authorPeter LaFosse <peter@vector35.com>2022-01-20 13:17:41 -0500
committerPeter LaFosse <peter@vector35.com>2022-01-20 13:17:41 -0500
commitd7dae709f93ef24516ae2db2f1f0d0ee333764f5 (patch)
tree548ff46b743ca644ff16007b9411539e01ffdd3b /python/lowlevelil.py
parent65c1ab279b34f11070a450de993886df9c7353ec (diff)
Rework IL inheritance for Call instructions
Diffstat (limited to 'python/lowlevelil.py')
-rw-r--r--python/lowlevelil.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/python/lowlevelil.py b/python/lowlevelil.py
index cda851d0..e255b431 100644
--- a/python/lowlevelil.py
+++ b/python/lowlevelil.py
@@ -36,8 +36,8 @@ from . import binaryview
from . import architecture
from . import types
from .interaction import show_graph_report
-from .commonil import (BaseILInstruction, Constant, BinaryOperation, UnaryOperation, Comparison, SSA,
- Phi, FloatingPoint, ControlFlow, Terminal, Call, StackOperation, Return,
+from .commonil import (BaseILInstruction, Constant, BinaryOperation, Tailcall, UnaryOperation, Comparison, SSA,
+ Phi, FloatingPoint, ControlFlow, Terminal, Syscall, Localcall, StackOperation, Return,
Signed, Arithmetic, Carry, DoublePrecision, Memory, Load, Store, RegisterStack, SetReg)
ExpressionIndex = NewType('ExpressionIndex', int)
@@ -1076,7 +1076,7 @@ class LowLevelILNoret(LowLevelILInstruction, Terminal):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILSyscall(LowLevelILInstruction, Call):
+class LowLevelILSyscall(LowLevelILInstruction, Syscall):
pass
@@ -1133,7 +1133,7 @@ class LowLevelILJump(LowLevelILInstruction, Terminal):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILCall(LowLevelILInstruction, Call):
+class LowLevelILCall(LowLevelILInstruction, Localcall):
@property
def dest(self) -> LowLevelILInstruction:
@@ -1145,7 +1145,7 @@ class LowLevelILCall(LowLevelILInstruction, Call):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILTailcall(LowLevelILInstruction, Call):
+class LowLevelILTailcall(LowLevelILInstruction, Tailcall):
@property
def dest(self) -> LowLevelILInstruction:
@@ -2192,7 +2192,7 @@ class LowLevelILRrc(LowLevelILCarryBase):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILCallStackAdjust(LowLevelILInstruction, Call):
+class LowLevelILCallStackAdjust(LowLevelILInstruction, Localcall):
@property
def dest(self) -> LowLevelILInstruction:
@@ -2371,7 +2371,7 @@ class LowLevelILRegStackFreeRelSsa(LowLevelILInstruction, RegisterStack, SSA):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILSyscallSsa(LowLevelILInstruction, Call, SSA):
+class LowLevelILSyscallSsa(LowLevelILInstruction, Syscall, SSA):
@property
def output(self) -> LowLevelILInstruction:
@@ -2415,7 +2415,7 @@ class LowLevelILSetRegStackRelSsa(LowLevelILInstruction, RegisterStack, SSA):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILCallSsa(LowLevelILInstruction, Call, SSA):
+class LowLevelILCallSsa(LowLevelILInstruction, Localcall, SSA):
@property
def output(self) -> LowLevelILInstruction:
@@ -2439,7 +2439,7 @@ class LowLevelILCallSsa(LowLevelILInstruction, Call, SSA):
@dataclass(frozen=True, repr=False, eq=False)
-class LowLevelILTailcallSsa(LowLevelILInstruction, Call, SSA, Terminal):
+class LowLevelILTailcallSsa(LowLevelILInstruction, Tailcall, SSA, Terminal):
@property
def output(self) -> LowLevelILInstruction: